# gimodules-python

## Information on how to distribute this package can be found here
https://packaging.python.org/en/latest/tutorials/packaging-projects/


## tests

run tests locally:

$ `pipenv run test -v` 

or 

$ `pytest`